@@ -26,6 +26,7 @@ def main():
     parser.add_argument("-D", "--delete-them", help="Whenever a file is found with identical contents to a previously discovered file, delete the new one.  This option is dangerous.", action='store_true')
     parser.add_argument("-m", "--min-size", help="Ignore files smaller than this (default %d)." % DEFAULT_MINSIZE, default=DEFAULT_MINSIZE, type=int, metavar='M')
     parser.add_argument("-p", "--profiles", help="Generate a profile of your files which doesn't contain very much potentially-sensitive information (it contains only the file sizes rounded up to 4096 bytes, how many files were duplicates, and an 16-bit checksum of each file).  This could be useful for a p2p storage project to measure how valuable convergent encryption is.", default=DEFAULT_PROFILES, action='store_true')
+    parser.add_argument("-n", "--no-follow-symlinks", help="Do not follow symlinks.", default=DEFAULT_PROFILES, action='store_true')
     parser.add_argument("dir", nargs='*', help="directories to recursively examine (default '.')", default=".")
     args = parser.parse_args()
 
@@ -33,5 +34,5 @@ def main():
         print "Please choose only one of .--hard-link_them. and '--delete-them'."
         sys.exit(-1)
 
-    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs.split(','), args.hard_link_them, args.delete_them, args.min_size, args.profiles, args.dir)
+    return dupfilefind.dffem(len(args.verbose), args.ignore_dirs.split(','), args.hard_link_them, args.delete_them, args.min_size, args.profiles, args.no_follow_symlinks, args.dir)
 
